powered by
Retrieve the NEWS file of a package as a character vector.
news(package, installed_only = FALSE, allow_changelog = TRUE, width = NULL)
Character string giving the name of an R package.
Only check installed packages.
Whether to try and find a ChangeLog file if the NEWS can't be found.
An optional positive integer - see base::strwrap().
base::strwrap()
A character vector containing the contents of the package's NEWS file (or possibly the ChangeLog file, if allow_changelog = TRUE). An error is thrown if no news could be found.
allow_changelog = TRUE
# NOT RUN { # } # NOT RUN { news("pkgnews") # } # NOT RUN { # }
Run the code above in your browser using DataLab